{{ fullname | escape | underline}}

.. automodule:: {{ fullname }}
   {%- if synopsis is defined %}
   :synopsis: {{ synopsis.get(fullname, '') }}
   {%- endif %}

   {% block classes %}
   {%- if classes %}
   .. rubric:: {{ _('Classes') }}
   .. autosummary::
      :toctree:
   {% for item in classes %}
      {{ item }}
   {%- endfor %}
   {%- endif %}
   {%- endblock %}

   {% block exceptions %}
   {%- if exceptions %}
   .. rubric:: {{ _('Exceptions') }}
   .. autosummary::
      :toctree:
   {% for item in exceptions %}
      {{ item }}
   {%- endfor %}
   {%- endif %}
   {%- endblock %}

   {% block functions %}
   {%- if functions %}
   .. rubric:: {{ _('Functions') }}
   .. autosummary::
      :toctree:
   {% for item in functions %}
      {{ item }}
   {%- endfor %}
   {%- endif %}
   {%- endblock %}

   {% block attributes %}
   {%- if attributes %}
   .. rubric:: {{ _('Attributes') }}
   .. autosummary::
      :toctree:
   {% for item in attributes %}
      {{ item }}
   {%- endfor %}
   {%- endif %}
   {%- endblock %}

{% block modules %}
{%- if modules %}
.. rubric:: {{ _('Modules') }}
.. autosummary::
   :toctree:
   :recursive:
{% for item in modules %}
   {{ item }}
{%- endfor %}
{%- endif %}
{%- endblock %}
